@@ -92,13 +92,29 @@ class AkshareDataset:
     def stock_rank(date: str) -> DataFrame:
         return ak.stock_rank_forecast_cninfo(date)
 
+    @staticmethod
+    def bond_spot(bond_id: str) -> DataFrame:
+        codes = bond_id.split('.')
+        if codes[1] == 'SH':
+            bond_id = 'sh' + codes[0]
+        elif codes[1] == 'SZ':
+            bond_id = 'sz' + codes[0]
+        dataset = ak.bond_zh_hs_cov_spot()
+        return dataset[dataset['symbol'] == bond_id]
+
     @staticmethod
     def bond_date(bond_id: str, start_date: str, end_date: str) -> DataFrame:
         dataset = ak.bond_zh_hs_daily(bond_id)
         return dataset
 
+    @staticmethod
+    def bond_info_all_jsl(cookie: str) -> DataFrame:
+        dataset = ak.bond_cb_jsl()
+        return dataset
+
     @staticmethod
     def bond_info_all() -> DataFrame:
+        ak.bond_cb_jsl()
         dataset = ak.bond_zh_cov()
         dataset = pd.DataFrame({
             'bond_id': dataset['债券代码'],
@@ -116,6 +132,9 @@ class AkshareDataset:
         # drop bond.bk
         dataset = dataset[~dataset['bond_id'].str.startswith('40')]
 
+        # drop price nan
+        dataset = dataset[dataset['price'] > 0]
+
         # add bond id suffix
         def add_bond_suffix(bond: int):
             if str(bond).startswith('12'):
@@ -139,7 +158,6 @@ class AkshareDataset:
                 return stock
 
         dataset['stock_id'] = dataset['stock_id'].apply(add_stock_suffix)
-        print(dataset.to_string())
         return dataset
 
     @staticmethod
